@@ -3,6 +3,16 @@
 # written by Liam Revell 2011
 
 phylANOVA<-function(tree,x,y,nsim=1000,posthoc=TRUE,p.adj="holm"){
+	if(is.null(names(x))){
+		cat("Warning: no labels for x. Assuming order of tree$tip.label.\n\n")
+		names(x)<-tree$tip.label
+	}
+	x<-x[tree$tip.label]
+	if(is.null(names(y))){
+		cat("Warning: no labels for y. Assuming order of tree$tip.label.\n\n")
+		names(y)<-tree$tip.label
+	}	
+	y<-y[tree$tip.label]
 	if(class(tree)!="phylo") stop("tree should be an object of class 'phylo.'")
 	sig2<-mean(pic(y,multi2di(tree))^2) # compute BM rate for y
 	x<-as.factor(x) # change x to factor
